Documentation
¶
Overview ¶
Package server provides a server implementation to connect network transport protocols and service business logic by defining server endpoints.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsInvalidConfig ¶
IsInvalidConfig asserts invalidConfigError.
Types ¶
type Config ¶
type Config struct {
// Dependencies.
Logger micrologger.Logger
Router *mux.Router
Service *service.Service
TransactionResponder microtransaction.Responder
// Settings.
ServiceName string
}
Config represents the configuration used to create a new server object.
func DefaultConfig ¶
func DefaultConfig() Config
DefaultConfig provides a default configuration to create a new server object by best effort.
Click to show internal directories.
Click to hide internal directories.